==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/search/classes_73.js <==
var searchData=
[
  ['scalar',['scalar',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html',1,'viennacl::linalg::opencl::kernels']]],
  ['scalar',['scalar',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20char_20_3e',['scalar< char >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20double_20_3e',['scalar< double >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20float_20_3e',['scalar< float >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20int_20_3e',['scalar< int >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20long_20_3e',['scalar< long >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20short_20_3e',['scalar< short >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20unsigned_20char_20_3e',['scalar< unsigned char >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20unsigned_20int_20_3e',['scalar< unsigned int >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20unsigned_20long_20_3e',['scalar< unsigned long >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20unsigned_20short_20_3e',['scalar< unsigned short >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_5fexpression',['scalar_expression',['../classviennacl_1_1scalar__expression.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5finner_5fprod_20_3e',['scalar_expression< LHS, RHS, op_inner_prod >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__inner__prod_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fmax_20_3e',['scalar_expression< LHS, RHS, op_max >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__max_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fmin_20_3e',['scalar_expression< LHS, RHS, op_min >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__min_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5f1_20_3e',['scalar_expression< LHS, RHS, op_norm_1 >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__1_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5f2_20_3e',['scalar_expression< LHS, RHS, op_norm_2 >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5ffrobenius_20_3e',['scalar_expression< LHS, RHS, op_norm_frobenius >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5finf_20_3e',['scalar_expression< LHS, RHS, op_norm_inf >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fsum_20_3e',['scalar_expression< LHS, RHS, op_sum >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__sum_01_4.html',1,'viennacl']]],
  ['scalar_5fmatrix',['scalar_matrix',['../classviennacl_1_1scalar__matrix.html',1,'viennacl']]],
  ['scalar_5fvector',['scalar_vector',['../structviennacl_1_1scalar__vector.html',1,'viennacl']]],
  ['scalartype_5fsize_5ffun',['scalartype_size_fun',['../structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html',1,'viennacl::device_specific::utils']]],
  ['scan',['scan',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scan.html',1,'viennacl::linalg::opencl::kernels']]],
  ['sha1',['sha1',['../classviennacl_1_1tools_1_1detail_1_1sha1.html',1,'viennacl::tools::detail']]],
  ['shared_5fptr',['shared_ptr',['../classviennacl_1_1tools_1_1shared__ptr.html',1,'viennacl::tools']]],
  ['shared_5fptr_3c_20char_20_3e',['shared_ptr< char >',['../classviennacl_1_1tools_1_1shared__ptr.html',1,'viennacl::tools']]],
  ['size1_5ffun',['size1_fun',['../structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html',1,'viennacl::device_specific::utils']]],
  ['size2_5ffun',['size2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html',1,'viennacl::device_specific::utils']]],
  ['size_5ffun',['size_fun',['../structviennacl_1_1device__specific_1_1utils_1_1size__fun.html',1,'viennacl::device_specific::utils']]],
  ['size_5ftype',['size_type',['../structviennacl_1_1result__of_1_1size__type.html',1,'viennacl::result_of']]],
  ['sliced_5fell_5fmatrix',['sliced_ell_matrix',['../classviennacl_1_1sliced__ell__matrix.html',1,'viennacl']]],
  ['sliced_5fell_5fmatrix_3c_20numerict_2c_20unsigned_20int_20_3e',['sliced_ell_matrix< NumericT, unsigned int >',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix_3_01_numeric_t_00_01unsigned_01int_01_4.html',1,'viennacl::linalg::opencl::kernels']]],
  ['spai',['spai',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1spai.html',1,'viennacl::linalg::opencl::kernels']]],
  ['spai_5fprecond',['spai_precond',['../classviennacl_1_1linalg_1_1spai__precond.html',1,'viennacl::linalg']]],
  ['spai_5fprecond_3c_20viennacl_3a_3acompressed_5fmatrix_3c_20scalartype_2c_20mat_5falignment_20_3e_20_3e',['spai_precond< viennacl::compressed_matrix< ScalarType, MAT_ALIGNMENT > >',['../classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html',1,'viennacl::linalg']]],
  ['spai_5ftag',['spai_tag',['../classviennacl_1_1linalg_1_1detail_1_1spai_1_1spai__tag.html',1,'viennacl::linalg::detail::spai']]],
  ['sparse_5fmatrix_5fadapted_5fiterator',['sparse_matrix_adapted_iterator',['../classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html',1,'viennacl::tools']]],
  ['sparse_5fmatrix_5fadapter',['sparse_matrix_adapter',['../classviennacl_1_1tools_1_1sparse__matrix__adapter.html',1,'viennacl::tools']]],
  ['sparse_5fvector',['sparse_vector',['../classviennacl_1_1linalg_1_1detail_1_1spai_1_1sparse__vector.html',1,'viennacl::linalg::detail::spai']]],
  ['spgemm_5foutput_5fwrite_5fdisabled',['spgemm_output_write_disabled',['../structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__disabled.html',1,'viennacl::linalg::host_based']]],
  ['spgemm_5foutput_5fwrite_5fenabled',['spgemm_output_write_enabled',['../structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__enabled.html',1,'viennacl::linalg::host_based']]],
  ['start1_5ffun',['start1_fun',['../structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html',1,'viennacl::device_specific::utils']]],
  ['start2_5ffun',['start2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html',1,'viennacl::device_specific::utils']]],
  ['statement',['statement',['../classviennacl_1_1scheduler_1_1statement.html',1,'viennacl::scheduler']]],
  ['statement_5fnode',['statement_node',['../structviennacl_1_1scheduler_1_1statement__node.html',1,'viennacl::scheduler']]],
  ['statement_5fnot_5fsupported_5fexception',['statement_not_supported_exception',['../classviennacl_1_1scheduler_1_1statement__not__supported__exception.html',1,'viennacl::scheduler']]],
  ['statement_5frepresentation_5ffunctor',['statement_representation_functor',['../classviennacl_1_1device__specific_1_1tree__parsing_1_1statement__representation__functor.html',1,'viennacl::device_specific::tree_parsing']]],
  ['statements_5fcontainer',['statements_container',['../classviennacl_1_1device__specific_1_1statements__container.html',1,'viennacl::device_specific']]],
  ['stride1_5ffun',['stride1_fun',['../structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html',1,'viennacl::device_specific::utils']]],
  ['stride2_5ffun',['stride2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html',1,'viennacl::device_specific::utils']]],
  ['stride_5ffun',['stride_fun',['../structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html',1,'viennacl::device_specific::utils']]],
  ['svd',['svd',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1svd.html',1,'viennacl::linalg::opencl::kernels']]],
  ['symbolic_5fbinder',['symbolic_binder',['../classviennacl_1_1device__specific_1_1symbolic__binder.html',1,'viennacl::device_specific']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/classes_73.js <==
var searchData=
[
  ['scalar',['scalar',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html',1,'viennacl::linalg::opencl::kernels']]],
  ['scalar',['scalar',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20char_20_3e',['scalar< char >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20double_20_3e',['scalar< double >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20float_20_3e',['scalar< float >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20int_20_3e',['scalar< int >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20long_20_3e',['scalar< long >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20short_20_3e',['scalar< short >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20unsigned_20char_20_3e',['scalar< unsigned char >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20unsigned_20int_20_3e',['scalar< unsigned int >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20unsigned_20long_20_3e',['scalar< unsigned long >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_3c_20unsigned_20short_20_3e',['scalar< unsigned short >',['../classviennacl_1_1scalar.html',1,'viennacl']]],
  ['scalar_5fexpression',['scalar_expression',['../classviennacl_1_1scalar__expression.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5finner_5fprod_20_3e',['scalar_expression< LHS, RHS, op_inner_prod >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__inner__prod_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fmax_20_3e',['scalar_expression< LHS, RHS, op_max >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__max_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fmin_20_3e',['scalar_expression< LHS, RHS, op_min >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__min_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5f1_20_3e',['scalar_expression< LHS, RHS, op_norm_1 >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__1_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5f2_20_3e',['scalar_expression< LHS, RHS, op_norm_2 >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5ffrobenius_20_3e',['scalar_expression< LHS, RHS, op_norm_frobenius >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fnorm_5finf_20_3e',['scalar_expression< LHS, RHS, op_norm_inf >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html',1,'viennacl']]],
  ['scalar_5fexpression_3c_20lhs_2c_20rhs_2c_20op_5fsum_20_3e',['scalar_expression< LHS, RHS, op_sum >',['../classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__sum_01_4.html',1,'viennacl']]],
  ['scalar_5fmatrix',['scalar_matrix',['../classviennacl_1_1scalar__matrix.html',1,'viennacl']]],
  ['scalar_5fvector',['scalar_vector',['../structviennacl_1_1scalar__vector.html',1,'viennacl']]],
  ['scalartype_5fsize_5ffun',['scalartype_size_fun',['../structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html',1,'viennacl::device_specific::utils']]],
  ['scan',['scan',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scan.html',1,'viennacl::linalg::opencl::kernels']]],
  ['sha1',['sha1',['../classviennacl_1_1tools_1_1detail_1_1sha1.html',1,'viennacl::tools::detail']]],
  ['shared_5fptr',['shared_ptr',['../classviennacl_1_1tools_1_1shared__ptr.html',1,'viennacl::tools']]],
  ['shared_5fptr_3c_20char_20_3e',['shared_ptr< char >',['../classviennacl_1_1tools_1_1shared__ptr.html',1,'viennacl::tools']]],
  ['size1_5ffun',['size1_fun',['../structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html',1,'viennacl::device_specific::utils']]],
  ['size2_5ffun',['size2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html',1,'viennacl::device_specific::utils']]],
  ['size_5ffun',['size_fun',['../structviennacl_1_1device__specific_1_1utils_1_1size__fun.html',1,'viennacl::device_specific::utils']]],
  ['size_5ftype',['size_type',['../structviennacl_1_1result__of_1_1size__type.html',1,'viennacl::result_of']]],
  ['sliced_5fell_5fmatrix',['sliced_ell_matrix',['../classviennacl_1_1sliced__ell__matrix.html',1,'viennacl']]],
  ['sliced_5fell_5fmatrix_3c_20numerict_2c_20unsigned_20int_20_3e',['sliced_ell_matrix< NumericT, unsigned int >',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix_3_01_numeric_t_00_01unsigned_01int_01_4.html',1,'viennacl::linalg::opencl::kernels']]],
  ['spai',['spai',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1spai.html',1,'viennacl::linalg::opencl::kernels']]],
  ['spai_5fprecond',['spai_precond',['../classviennacl_1_1linalg_1_1spai__precond.html',1,'viennacl::linalg']]],
  ['spai_5fprecond_3c_20viennacl_3a_3acompressed_5fmatrix_3c_20scalartype_2c_20mat_5falignment_20_3e_20_3e',['spai_precond< viennacl::compressed_matrix< ScalarType, MAT_ALIGNMENT > >',['../classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html',1,'viennacl::linalg']]],
  ['spai_5ftag',['spai_tag',['../classviennacl_1_1linalg_1_1detail_1_1spai_1_1spai__tag.html',1,'viennacl::linalg::detail::spai']]],
  ['sparse_5fmatrix_5fadapted_5fiterator',['sparse_matrix_adapted_iterator',['../classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html',1,'viennacl::tools']]],
  ['sparse_5fmatrix_5fadapter',['sparse_matrix_adapter',['../classviennacl_1_1tools_1_1sparse__matrix__adapter.html',1,'viennacl::tools']]],
  ['sparse_5fvector',['sparse_vector',['../classviennacl_1_1linalg_1_1detail_1_1spai_1_1sparse__vector.html',1,'viennacl::linalg::detail::spai']]],
  ['spgemm_5foutput_5fwrite_5fdisabled',['spgemm_output_write_disabled',['../structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__disabled.html',1,'viennacl::linalg::host_based']]],
  ['spgemm_5foutput_5fwrite_5fenabled',['spgemm_output_write_enabled',['../structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__enabled.html',1,'viennacl::linalg::host_based']]],
  ['spmv_5falpha_5fbeta',['spmv_alpha_beta',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1spmv__alpha__beta.html',1,'viennacl::linalg::cuda::detail']]],
  ['spmv_5fpure',['spmv_pure',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1spmv__pure.html',1,'viennacl::linalg::cuda::detail']]],
  ['start1_5ffun',['start1_fun',['../structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html',1,'viennacl::device_specific::utils']]],
  ['start2_5ffun',['start2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html',1,'viennacl::device_specific::utils']]],
  ['statement',['statement',['../classviennacl_1_1scheduler_1_1statement.html',1,'viennacl::scheduler']]],
  ['statement_5fnode',['statement_node',['../structviennacl_1_1scheduler_1_1statement__node.html',1,'viennacl::scheduler']]],
  ['statement_5fnot_5fsupported_5fexception',['statement_not_supported_exception',['../classviennacl_1_1scheduler_1_1statement__not__supported__exception.html',1,'viennacl::scheduler']]],
  ['statement_5frepresentation_5ffunctor',['statement_representation_functor',['../classviennacl_1_1device__specific_1_1tree__parsing_1_1statement__representation__functor.html',1,'viennacl::device_specific::tree_parsing']]],
  ['statements_5fcontainer',['statements_container',['../classviennacl_1_1device__specific_1_1statements__container.html',1,'viennacl::device_specific']]],
  ['stride1_5ffun',['stride1_fun',['../structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html',1,'viennacl::device_specific::utils']]],
  ['stride2_5ffun',['stride2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html',1,'viennacl::device_specific::utils']]],
  ['stride_5ffun',['stride_fun',['../structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html',1,'viennacl::device_specific::utils']]],
  ['svd',['svd',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1svd.html',1,'viennacl::linalg::opencl::kernels']]],
  ['symbolic_5fbinder',['symbolic_binder',['../classviennacl_1_1device__specific_1_1symbolic__binder.html',1,'viennacl::device_specific']]]
];
